var testServerPort = 9295,
    Blitz = require('../lib/blitz.js');

//needed by the mock server to compare usernames
process.env['BLITZ_API_USER'] = 'user';

describe("Blitz", function () {
    var blitz;
    
    beforeEach(function () {
        blitz = new Blitz('user', 'key', 'localhost', 9295);
    });
    
    it("should return a Rush Result object", function () {
        var finished = false;
        runs (function() {
            blitz.rush({
                    user: 'c123',
                    pattern: {intervals: []},
                    steps: [
                        {url: 'http://127.0.0.1'},
                        {url: 'http://127.0.0.1/2'}
                    ]
                }).on('complete', function (data) {
                expect(data.region).toBeDefined();
                expect(data.timeline).toBeDefined();
                expect(data.timeline[0].steps).toBeDefined();
                expect(data.timeline[0].steps.length).toEqual(2);
                finished = true;
            });
        });
        waitsFor(function () {
            return finished;
        });
    });

    it("should return a Sprint Result object", function () {
        var finished = false;
        runs (function() {
            blitz.sprint({
                    steps: [
                        {url: 'http://127.0.0.1'},
                        {url: 'http://127.0.0.1/2'}
                    ]
                }).on('complete', function (data) {
                    expect(data.region).toBeDefined();
                    expect(data.duration).toBeDefined();
                    expect(data.steps).toBeDefined();
                    expect(data.steps.length).toEqual(2);
                    finished = true;
                });
        });
        waitsFor(function () {
            return finished;
        });
    });

    it("should fail Rush if pattern is not given", function () {
        var finished = false;
        // run a sprint to authenticate
        runs (function () {
            blitz.sprint({
                steps: [
                    {url: 'http://127.0.0.1'},
                    {url: 'http://127.0.0.1/2'}
                ]
            }).on('complete', function (data) {
                //now we can run a rush
                expect(function () {
                    blitz.rush({
                        user: 'c123',
                        steps: [{url: 'http://127.0.0.1'}] 
                    });  
                }).toThrow('missing pattern');
                finished = true;
            });
        });
        waitsFor (function() {
            return finished;
        });
    });
    
    it("should be authenticated", function () {
        var b = new Blitz('user', 'key', 'localhost', 9295, true);
        expect(b.authenticated).toBeTruthy();
    });
    
    it("should authenticates", function () {
        var finished = false;
        runs (function() {
            expect(blitz.authenticated).toBeFalsy();
            blitz.sprint(
                {
                    steps: [
                        {url: 'http://127.0.0.1'},
                        {url: 'http://127.0.0.1/2'}
                    ]
                }).on('complete', function (data) {
                    expect(blitz.authenticated).toBeTruthy();
                    finished = true;
                });
        });
        waitsFor(function () {
            return finished;
        });
    });
});
